@@ -1,3 +1,14 @@
+HOP_BY_HOP = [
+    'connection',
+    'keep-alive',
+    'aroxy-authenticate',
+    'roxy-authorization',
+    'te',
+    'trailers',
+    'transfer-encoding',
+    'upgrade'
+]
+
 RESTFUL_HEADER = {
     'Content-type': 'application/json',
     'Accept': 'application/json',
@@ -7,12 +18,17 @@ RESTFUL_HEADER = {
 HTTP_API_KEY = 'HTTP_API_KEY'
 HTTP_USER_TOKEN = 'HTTP_USER_TOKEN'
 HTTP_FROM = 'HTTP_X_FORWARDED_FOR'
+HTTP_SERVER = 'Server'
 
 # Header names from response
 USER_TOKEN = 'user-token'
 API_KEY = 'api-key'
 CLIENT_IP = 'client-ip'
 
+# Response headers
+HEADER_SERVER = 'Server'
+VALUE_SERVER = 'Django Proxy Server'
+
 # Response content
 MESSAGE = 'message'
 SUCCESS = 'success'
