@@ -65,6 +65,10 @@ def expose_service(methods, public=False):
                                 error_message = 'Method Not Allowed'
                                 raise Exception
 
+                            request.DATA = dict()
+                            if request.body:
+                                request.DATA.update(json.loads(request.body))
+
                             return view_func(request, *args, **kwargs)
 
                     else:
@@ -77,6 +81,7 @@ def expose_service(methods, public=False):
                     raise Exception
 
             except Exception as e:
+                print e
                 if error_message is None:
                     if e.message is not None:
                         error_message = e.message
